@@ -1,10 +1,10 @@
-class unit_test_x:
+class UnitTestX:
     def __init__(self):
         self.a = 1
         self.b = 2
 
 
-class unit_test_y:
+class UnitTestY:
     def __init__(self):
         self.c = 3
-        self.d = unit_test_x()
+        self.d = UnitTestX()
